Stan Math Library: stan/math/prim/scal/fun/logical_and.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

logical_and.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_LOGICAL_AND_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_LOGICAL_AND_HPP
3
4 namespace stan {
5 namespace math {
6
28 template <typename T1, typename T2>
29 inline int
30 logical_and(const T1 x1, const T2 x2) {
31 return (x1 != 0) && (x2 != 0);
32 }
33
34 }
35 }
36
37 #endif
stan::math::logical_and
int logical_and(const T1 x1, const T2 x2)
The logical and function which returns 1 if both arguments are unequal to zero and 0 otherwise...
Definition: logical_and.hpp:30
stan
Definition: log_sum_exp.hpp:8

[ Stan Home Page ] © 2011–2016, Stan Development Team.